/**
 * OW2 Util
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: EarDeployableMetadata.java 3224 2008-05-15 09:37:33Z gaellalire $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.ear.impl;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import org.ow2.util.ee.deploy.api.deployable.EARDeployable;
import org.ow2.util.ee.metadata.car.api.ICarDeployableMetadata;
import org.ow2.util.ee.metadata.ear.api.IEarDeployableMetadata;
import org.ow2.util.ee.metadata.war.api.IWarDeployableMetadata;

/**
 * Implementation of ear deployable metadata.
 * @author Gael Lalire
 */
public class EarDeployableMetadata implements IEarDeployableMetadata {

    /**
     * List of car deployable.
     */
    private List<ICarDeployableMetadata> carDeployableMetadataList;

    /**
     * List of war deployable.
     */
    private List<IWarDeployableMetadata> warDeployableMetadataList;

    /**
     * The ear deployable.
     */
    private EARDeployable earDeployable;

    /**
     * Constructor.
     * @param earDeployable the ear deployable
     */
    public EarDeployableMetadata(final EARDeployable earDeployable) {
        this.earDeployable = earDeployable;
        carDeployableMetadataList = new ArrayList<ICarDeployableMetadata>();
        warDeployableMetadataList = new ArrayList<IWarDeployableMetadata>();
    }

    /**
     * Add a car deployable metadata.
     * @param carDeployableMetadata the car deployable metadata to add
     */
    public void addCarDeployableMetadata(final ICarDeployableMetadata carDeployableMetadata) {
        carDeployableMetadataList.add(carDeployableMetadata);
    }

    /**
     * Add a war deployable metadata.
     * @param warDeployableMetadata the war deployable metadata to add
     */
    public void addWarDeployableMetadata(final IWarDeployableMetadata warDeployableMetadata) {
        warDeployableMetadataList.add(warDeployableMetadata);
    }

    /**
     * @return a collection of client archive metadata.
     */
    public Collection<ICarDeployableMetadata> getCarDeployableMetadataCollection() {
        return carDeployableMetadataList;
    }

    /**
     * @return a collection of web archive metadata.
     */
    public Collection<IWarDeployableMetadata> getWarDeployableMetadataCollection() {
        return warDeployableMetadataList;
    }

    /**
     * @return the ear deployable
     */
    public EARDeployable getDeployable() {
        return earDeployable;
    }

}
