/**
 * OW2 Util
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: EarDeployableMetadataFactory.java 3279 2008-05-21 16:00:00Z gaellalire $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.ear.impl;

import java.util.ArrayList;
import java.util.List;

import org.ow2.util.archive.api.IArchive;
import org.ow2.util.ee.deploy.api.deployable.CARDeployable;
import org.ow2.util.ee.deploy.api.deployable.EARDeployable;
import org.ow2.util.ee.deploy.api.deployable.LibDeployable;
import org.ow2.util.ee.deploy.api.deployable.WARDeployable;
import org.ow2.util.ee.deploy.api.deployable.metadata.DeployableMetadataException;
import org.ow2.util.ee.metadata.car.api.ICarDeployableMetadata;
import org.ow2.util.ee.metadata.car.impl.CarDeployableMetadataFactory;
import org.ow2.util.ee.metadata.car.impl.CarExternLibraries;
import org.ow2.util.ee.metadata.ear.api.IEarDeployableMetadata;
import org.ow2.util.ee.metadata.ear.api.IEarDeployableMetadataFactory;
import org.ow2.util.ee.metadata.war.api.IWarDeployableMetadata;
import org.ow2.util.ee.metadata.war.impl.WarDeployableMetadataFactory;
import org.ow2.util.ee.metadata.war.impl.WarExternLibraries;
import org.ow2.util.scan.api.ArchiveScannerFactory;
import org.ow2.util.scan.api.ScanException;

/**
 * Implementation of ear deployable metadata.
 * @author Gael Lalire
 */
public class EarDeployableMetadataFactory implements IEarDeployableMetadataFactory {

    private ArchiveScannerFactory archiveScannerFactory;

    private WarDeployableMetadataFactory warDeployableMetadataFactory;

    private CarDeployableMetadataFactory carDeployableMetadataFactory;

    public EarDeployableMetadataFactory() throws ScanException {
        this(ArchiveScannerFactory.getInstance());
    }

    public EarDeployableMetadataFactory(final ArchiveScannerFactory archiveScannerFactory) {
        this.archiveScannerFactory = archiveScannerFactory;
        warDeployableMetadataFactory = new WarDeployableMetadataFactory(archiveScannerFactory);
        carDeployableMetadataFactory = new CarDeployableMetadataFactory(archiveScannerFactory);
    }

    /**
     * @param deployable the ear deployable (getOriginalDeployable must not be null ie it's
     * already decompressed archive)
     * @return a new ear deployable metadata
     * @throws DeployableMetadataException if ear is not uncompressed
     */
    public IEarDeployableMetadata createDeployableMetadata(final EARDeployable deployable) throws DeployableMetadataException {
        if (deployable.getOriginalDeployable() == null) {
            throw new DeployableMetadataException("ear archive must be uncompressed");
        }
        List<LibDeployable> libDeployableList = deployable.getLibDeployables();
        List<IArchive> libArchiveList = new ArrayList<IArchive>();
        for (LibDeployable libDeployable : libDeployableList) {
            libArchiveList.add(libDeployable.getArchive());
        }
        EarDeployableMetadata earDeployableMetadata = new EarDeployableMetadata(deployable);

        // war
        WarExternLibraries warExternLibraries = new WarExternLibraries(archiveScannerFactory, libArchiveList);
        for (WARDeployable warDeployable : deployable.getWARDeployables()) {
            IWarDeployableMetadata warDeployableMetadata = warDeployableMetadataFactory.createDeployableMetadata(warDeployable,
                    warExternLibraries, null);
            earDeployableMetadata.addWarDeployableMetadata(warDeployableMetadata);
        }
        warExternLibraries.close();

        // car

        CarExternLibraries carExternLibraries = new CarExternLibraries(archiveScannerFactory, libArchiveList);
        for (CARDeployable carDeployable : deployable.getCARDeployables()) {
            ICarDeployableMetadata carDeployableMetadata = carDeployableMetadataFactory.createDeployableMetadata(carDeployable,
                    carExternLibraries);
            earDeployableMetadata.addCarDeployableMetadata(carDeployableMetadata);
        }
        carExternLibraries.close();



        // ejb jar

        // EjbJarExternLibraries ejbJarExternLibraries = new EjbJarExternLibraries<EJB3Deployable>(archiveScannerFactory,
        // libArchiveList);

        return earDeployableMetadata;
    }

    /**
     * @return the supported class of this factory
     */
    public Class<IEarDeployableMetadata> getDeployableMetadataClass() {
        return IEarDeployableMetadata.class;
    }

}
